@@ -47,17 +47,19 @@ class DownloadBitwarden(object):
             "\nSuccessfully extracted BitWarden binary to {}\n".format(path_to_exe_file)
         )
 
-        if platform.system().lower() == 'windows':
+        if platform.system().lower() == "windows":
             environment_path_var: list = os.getenv("PATH").split(";")
-            file_name_with_extension: str = 'bw.exe'
+            file_name_with_extension: str = "bw.exe"
         else:
             environment_path_var: list = os.getenv("PATH").split(":")[1:]
-            file_name_with_extension: str = 'bw'
+            file_name_with_extension: str = "bw"
 
         # Try to move CLI binary to PATH
         for path_dir in environment_path_var:
             try:
-                Path(path_to_exe_file).rename(os.path.join(path_dir, file_name_with_extension))
+                Path(path_to_exe_file).rename(
+                    os.path.join(path_dir, file_name_with_extension)
+                )
                 path_to_exe_file = os.path.join(path_dir, file_name_with_extension)
                 moved = True
                 break
@@ -80,13 +82,4 @@ class DownloadBitwarden(object):
                 ["chmod", "+x", path_to_exe_file], capture_output=True, text=True
             )
 
-        print(
-            subprocess.run(
-                [path_to_exe_file, "--help"],
-                capture_output=True,
-                text=True,
-                timeout=180,
-            ).stdout
-        )
-
-        print("\nEnd of Bitwarden Output\n")
+        return path_to_exe_file
