@@ -1,6 +1,7 @@
 import os
 import subprocess
 import json
+import logging
 
 from .download_bitwarden import DownloadBitwarden
 
@@ -12,7 +13,7 @@ class Bitwarden(object):
 
     def __init__(self, bitwarden_credentials=None):
         """
-        bitwarden_credentials - dict with 'username' / 'password' keys
+        bitwarden_credentials - dict with 'password' / 'client_id' / 'client_secret' keys
         'bw' binary should be already in PATH
         """
         self.data = {}
@@ -29,12 +30,25 @@ class Bitwarden(object):
         Examples:
           - bw.bitwarden_exe('logout')
           - bw.bitwarden_exe(
-            "login",
-            self.bitwarden_credentials["username"],
+            "unlock",
             self.bitwarden_credentials["password"],
             "--raw",
             )
         """
+        env = {
+            **os.environ,
+        }
+
+        if (
+            self.bitwarden_credentials["client_id"]
+            and self.bitwarden_credentials["client_secret"]
+        ):
+            env["BW_CLIENTID"] = str(self.bitwarden_credentials["client_id"])
+            env["BW_CLIENTSECRET"] = str(self.bitwarden_credentials["client_secret"])
+            logging.info("Using provided client_id and client_secret")
+        else:
+            logging.info("Using client_id and client_secret from env vars")
+
         try:
             return subprocess.run(
                 [
@@ -44,6 +58,7 @@ class Bitwarden(object):
                 capture_output=True,
                 text=True,
                 timeout=180,
+                env=env,
             )
         except FileNotFoundError:
             self.path_to_exe_file = DownloadBitwarden.download_bitwarden()
@@ -55,29 +70,32 @@ class Bitwarden(object):
                 capture_output=True,
                 text=True,
                 timeout=180,
+                env=env,
             )
 
     def bitwarden_login(self):
         """
         Performs login opeartion via BitWarden CLI
-        Requires username / password already set when creation Bitwarden instance
+        Requires password / client_id / client_secret already set when creation Bitwarden instance
         """
-        retry_count = 0
         bitwarden_app = self.bitwarden_exe(
             "login",
-            self.bitwarden_credentials["username"],
-            self.bitwarden_credentials["password"],
-            "--raw",
+            "--apikey",
         )
-        while len(bitwarden_app.stdout) == 0 and retry_count < 5:
+
+        if "You are logged in!" in bitwarden_app.stdout:
             bitwarden_app = self.bitwarden_exe(
-                "login",
-                self.bitwarden_credentials["username"],
+                "unlock",
                 self.bitwarden_credentials["password"],
                 "--raw",
             )
-            retry_count += 1
-        self.bitwarden_token = bitwarden_app.stdout
+            self.bitwarden_token = bitwarden_app.stdout
+            if "Invalid master password" in self.bitwarden_token:
+                logging.error(bitwarden_app.stdout)
+                raise Exception("Invalid master password!")
+        else:
+            logging.error(bitwarden_app.stdout)
+            raise Exception("Failed to login via api key!")
 
     def get_credentials(self, user_credentials_name):
         """
@@ -113,6 +131,9 @@ class Bitwarden(object):
             self.bitwarden_token,
         )
 
+        if not bitwarden_app.stdout:
+            raise Exception("Empty items list! Probably some issue with loggin in")
+
         bitwarden_items = json.loads(bitwarden_app.stdout)
         for credentials_key, credentials_name in data.items():
             for bw_item in bitwarden_items:
@@ -143,6 +164,6 @@ class Bitwarden(object):
                         for field in bw_item["fields"]:
                             self.data[credentials_key][field["name"]] = field["value"]
         if len(self.data) != len(data):
-            print("Can't get data from bitwarden")
+            logging.error("Can't get data from bitwarden")
             raise Exception("Bitwarden ERROR")
         self.bitwarden_exe("logout")
